@@ -7,8 +7,8 @@
 
 """
 
-from docx2python import get_docx_content
+from docx2python import docx2python
 
 def test() -> None:
     """Just making sure the import works."""
-    get_docx_content('resources/example.docx')
\ No newline at end of file
+    docx2python('resources/example.docx')
\ No newline at end of file
